/*

iPodSCSICodePages

This project shows how to access the hidden XML data from the iPod's SCSI CodePages
This XML contains, amongst other things, the iPod's serial number and audio / video capabilities

version 1.0
30 Jan 2007
Dave Addey
http://www.thismuchiknow.co.uk/

Adapted from Apple's SCSIOldAndNew sample code v1.1, found at:
http://developer.apple.com/samplecode/SCSIOldAndNew/
        
*/

#include <Carbon/Carbon.h>
#include <CoreFoundation/CoreFoundation.h>
#include <IOKit/IOKitLib.h>
#include <IOKit/scsi-commands/SCSITaskLib.h>

// IO_OBJECT_NULL was added in Mac OS X 10.4. If it's not defined in the headers, define it ourselves.
// This allows the same code to build using the 10.4u SDK for Intel-based systems and earlier SDKs for backwards compatibility
// with PowerPC-based systems.
#ifndef IO_OBJECT_NULL
#define	IO_OBJECT_NULL	((io_object_t) 0)
#endif

// define a struct to contain the CodePage data we will be retrieving
typedef struct SCSICmd_INQUIRY_CodePageData
{
	UInt8		Padding1;
	UInt8		CodePage;
	UInt8		Padding2;
	UInt8		DataSize;
	char		Data[251];
} SCSICmd_INQUIRY_CodePageData;

bool ExecuteVPDInquiryUsingSTUC(SCSITaskDeviceInterface **interface, UInt32 inCodePage, SCSICmd_INQUIRY_CodePageData *inqBuffer);

void CreateDeviceInterfaceUsingSTUC(io_object_t scsiDevice, IOCFPlugInInterface ***thePlugInInterface, SCSITaskDeviceInterface ***theInterface);

void GetiPodXML(io_service_t scsiDevice);

void TestiPodsUsingSTUC(io_iterator_t iterator);

void CreateMatchingDictionaryForSTUC(CFMutableDictionaryRef *matchingDict);

boolean_t FindiPodsUsingSTUC(mach_port_t masterPort, io_iterator_t *iterator);