/*

iPodSCSICodePages

This project shows how to access the hidden XML data from the iPod's SCSI CodePages
This XML contains, amongst other things, the iPod's serial number and audio / video capabilities

version 1.0
30 Jan 2007
Dave Addey
http://www.thismuchiknow.co.uk/

Adapted from Apple's SCSIOldAndNew sample code v1.1, found at:
http://developer.apple.com/samplecode/SCSIOldAndNew/
        
*/

#include <Carbon/Carbon.h>
#include <IOKit/IOKitLib.h>
#include <IOKit/scsi-commands/SCSICmds_INQUIRY_Definitions.h>
#include "STUCMethod.h"

#define kCommandTestiPods							'00h '

void TestiPods()
{
    io_iterator_t	iterator = IO_OBJECT_NULL;
    
    if (FindiPodsUsingSTUC(kIOMasterPortDefault, &iterator)) {
		printf("Found iPods\n");	
        TestiPodsUsingSTUC(iterator);
    }
    else {
        fprintf(stderr, "No iPod devices found.\n");
    }
    
    if (iterator) {
        IOObjectRelease(iterator);
    }
}

// Handle command-process events at the application level
OSStatus DoAppCommandProcess(EventHandlerCallRef nextHandler, EventRef theEvent, void* userData)
{
    HICommand  aCommand;
    OSStatus   result;

    GetEventParameter(theEvent, kEventParamDirectObject, typeHICommand, NULL, sizeof(HICommand),
                      NULL, &aCommand);
    
    switch (aCommand.commandID) {
		case kCommandTestiPods:
			TestiPods();
			result = noErr;
			break;

        case kHICommandQuit:
            QuitApplicationEventLoop();
            result = noErr;
            break;
    
        default:
            result = eventNotHandledErr;
            break;
    }
    
    HiliteMenu(0);
    return result;
}

void InstallAppEvents(void)
{
    EventHandlerUPP	eventHandler;
    EventTypeSpec  	eventType;

    eventHandler = NewEventHandlerUPP(DoAppCommandProcess);
    eventType.eventClass = kEventClassCommand;
    eventType.eventKind = kEventCommandProcess;
    InstallApplicationEventHandler(eventHandler, 1, &eventType, NULL, NULL);
}

int main(int argc, char* argv[])
{
    IBNibRef 		nibRef;
    OSStatus		err;

    // Create a Nib reference passing the name of the nib file (without the .nib extension)
    // CreateNibReference only searches into the application bundle.
    err = CreateNibReference(CFSTR("Main"), &nibRef);
    require_noerr(err, CantGetNibRef);
    
    // Once the nib reference is created, set the menu bar. "MainMenu" is the name of the menu bar
    // object. This name is set in InterfaceBuilder when the nib is created.
    err = SetMenuBarFromNib(nibRef, CFSTR("MenuBar"));
    require_noerr(err, CantSetMenuBar);
    
    // We don't need the nib reference any more.
    DisposeNibReference(nibRef);
    
    // Install our application event handler.
    InstallAppEvents();

    // Call the event loop.
    RunApplicationEventLoop();

CantSetMenuBar:
CantGetNibRef:
    return err;
}

